@@ -310,50 +310,71 @@ def check_pki_role(name, mount_point, client):
         return None
 
 
-def compare_state(desired_state, current_state):
-    """Compares desiretd state to current state. Returns true if objects are equal
+def compare_state(desired_state, current_state, ignore=None):
+    """Compares desired state to current state. Returns true if objects are equal
 
-    Recursevlly walks dict object to compare all keys
+    Recursively walks dict object to compare all keys
 
-    :param desired_state: The the state user desires to have
-    :type desired_state: dict
-    :param current_state: The the state that currentlly is applied.
-    :type current_state: dict
+    :param desired_state: The state user desires.
+    :param current_state: The state that currently exists.
+    :param ignore: Ignore these keys.
+    :type ignore: list
 
-    :return: The JSON response of the request.
-    :rtype: requests.Response
+    :return: True if the states are the same.
+    :rtype: bool
     """
 
-    # list
+    if ignore is None:
+        ignore = []
     if (type(desired_state) is list):
-        # is [current_state] a list and of same length as [desired_state]?
         if ((type(current_state) != list) or (len(desired_state) != len(current_state))):
             return False
-        # Lists should not contain duplicates
         return set(desired_state) == set(current_state)
-        # desired_state = sorted(desired_state)
-        # current_state = sorted(current_state)
-        # # iterate over list items
-        # for list_index,list_item in enumerate(desired_state):
-        #     # compare [desired_state] list item against [current_state] at index
-        #     if (not compare_state(list_item,current_state[list_index])):
-        #         return False
-        # # list identical
-        # return True
 
-    # dictionary
     if (type(desired_state) is dict):
-        # is [current_state] a dictionary?
         if (type(current_state) != dict):
             return False
 
         # iterate over dictionary keys
-        for k, v in desired_state.items():
-            # key exists in [current_state] dictionary, and same value?
-            if ((k not in current_state) or (not compare_state(v, current_state.get(k)))):
+        for key in desired_state.keys():
+            if key in ignore:
+                continue
+            v = desired_state[key]
+            if ((key not in current_state) or (not compare_state(v, current_state.get(key)))):
                 return False
-        # dictionary identical
         return True
 
-    # simple value - compare both value and type for equality
+    # lots of things get handled as strings in ansible that aren't necessarily strings, can extend this list later.
+    if isinstance(desired_state, str) and isinstance(current_state, int):
+        current_state = str(current_state)
+
     return ((desired_state == current_state))
+
+
+def get_keys_updated(desired_state, current_state, ignore=None):
+    """Return list of keys that have different values
+
+    Recursively walks dict object to compare all keys
+
+    :param desired_state: The state user desires.
+    :type desired_state: dict
+    :param current_state: The state that currently exists.
+    :type current_state: dict
+    :param ignore: Ignore these keys.
+    :type ignore: list
+
+    :return: Different items
+    :rtype: list
+    """
+
+    if ignore is None:
+        ignore = []
+
+    differences = []
+    for key in desired_state.keys():
+        if key in ignore:
+            continue
+        v = desired_state[key]
+        if ((key not in current_state) or (not compare_state(v, current_state.get(key)))):
+            differences.append(key)
+    return differences
