@@ -59,8 +59,7 @@ def main():
     argspec['mount_point'] = dict(required=False, type='str', default=None)
     argspec['config'] = dict(required=False, type='dict',
                              default=DEFAULT_CONFIG)
-    supports_check_mode = True
-    module = hashivault_init(argspec, supports_check_mode=supports_check_mode)
+    module = hashivault_init(argspec, supports_check_mode=True)
     result = hashivault_auth_method(module)
     if result.get('failed'):
         module.fail_json(**result)
@@ -92,7 +91,7 @@ def hashivault_auth_method(module):
         auth_methods = result.get('data', result)
         if (mount_point + u"/") in auth_methods:
             exists = True
-    except:
+    except Exception:
         pass
 
     if state == 'enabled' and not exists:
@@ -126,5 +125,6 @@ def hashivault_auth_method(module):
 
     return {'changed': changed, 'created': create}
 
+
 if __name__ == '__main__':
     main()
